Spreadsheet_to_Dictionary converts a spreadsheet into a python dictionary. The current version (0.0.1) only supports locally saved files.
## How to use it
You can use the library by specifying the spreadsheet file location as an argument.
Optionally, you can also specify the name of the worksheet in the spreadsheet file.
If the column names were not defined in the first row, you can also specify the row number as well, where 1 is the first row.
## Repository
https://github.com/h4n53l/excel_to_dictionary